@@ -6,7 +6,9 @@ fixation duration or initial landing position.
 '''
 
 
-from .fixation import FixationSequence as _FixationSequence
+import numpy as _np
+from ._core import distance as _distance
+from .fixation import FixationSequence as _FixationSequence, Fixation as _Fixation
 from .text import TextBlock as _TextBlock, InterestArea as _InterestArea
 
 
@@ -109,30 +111,60 @@ def initial_landing_x(interest_areas, fixation_sequence):
 def duration_mass(text_block, fixation_sequence, n=1, gamma=30):
 	'''
 
-	Iterate over a sequence of fixations and, for each fixation,
-	distribute its duration across the line of text it is located inside
-	and return the sum of these distributions.
+	Given a `eyekit.text.TextBlock` and `eyekit.fixation.FixationSequence`,
+	distribute the durations of the fixations probabilistically across the
+	`eyekit.text.TextBlock`. Specifically, the duration of fixation *f* is
+	distributed over all characters *C* in its line according to the probability
+	that the reader is "seeing" each character (see `p_characters_fixation()`),
+	and this is summed over all fixations:
 
-	More specifically, we assume that the closer a character is to the
-	fixation point, the greater the probability that the participant is
-	"looking at" (i.e., processing) that character. Specifically, for a
-	given fixation *f*, we compute a Gaussian distribution over all
-	characters in the line according to:
+	$$\\sum_{f \\in F} p(C|f) \\cdot f_\\mathrm{dur}$$
+
+	Returns a 2D Numpy array, the sum of which is equal to the total duration of
+	all fixations. This can be passed to `eyekit.image.Image.render_heatmap()`
+	for visualization. Duration mass reveals the parts of the text that received
+	the most attention. Optionally, this can be performed over higher-level
+	ngrams by setting `n` > 1.
+
+	'''
+	if not isinstance(text_block, _TextBlock):
+		raise TypeError('text_block should be of type TextBlock')
+	if not isinstance(fixation_sequence, _FixationSequence):
+		raise TypeError('fixation_sequence should be of type FixationSequence')
+	distribution = _np.zeros((text_block.n_rows, text_block.n_cols-(n-1)), dtype=float)
+	for fixation in fixation_sequence.iter_without_discards():
+		distribution += p_characters_fixation(text_block, fixation, n=n, gamma=gamma) * fixation.duration
+	return distribution
+
+def p_characters_fixation(text_block, fixation, n=1, gamma=30):
+	'''
+
+	Given a `eyekit.text.TextBlock` and `eyekit.fixation.Fixation`, calculate the
+	probability that the reader is "seeing" each character in the text. We assume
+	that the closer a character is to the fixation point, the greater the
+	probability that the participant is "seeing" (i.e., processing) that
+	character. Specifically, for a given fixation *f*, we compute a Gaussian
+	distribution over all characters in the line according to:
 
 	$$p(c|f) \\propto \\mathrm{exp} \\frac{ -\\mathrm{ED}(f_\\mathrm{pos}, c_\\mathrm{pos})^2 }{2\\gamma^2}$$
 
-	where *γ* is a free parameter controlling the rate at which
-	probability decays with the Euclidean distance (ED) between the
-	position of fixation *f* and the position of character *c*. The
-	duration of fixation *f* is then distributed across the entire line
-	probabilistically and summed over all fixations in the fixation
-	sequence *F*, yielding what we refer to as "duration mass".
-
-	$$\\sum_{f \\in F} P(c|f) \\cdot f_\\mathrm{dur}$$
+	where *γ* (`gamma`) is a free parameter controlling the rate at which probability
+	decays with the Euclidean distance (ED) between the position of fixation *f*
+	and the position of character *c*.
 
+	Returns a 2D Numpy array representing a probability distribution over all
+	characters, with all its mass confined to the line that the fixation occurred
+	inside, and with greater mass closer to fixation points. This array can be
+	passed to `eyekit.image.Image.render_heatmap()` for visualization.
+	Optionally, this calculation can be performed over higher-level ngrams by
+	setting `n` > 1.
+	
 	'''
-	distributions = []
-	for fixation in fixation_sequence.iter_without_discards():
-		distribution = text_block.p_ngrams_fixation(fixation, n, gamma) * fixation.duration
-		distributions.append(distribution)
-	return sum(distributions)
+	if not isinstance(fixation, _Fixation):
+		raise TypeError('fixation should be of type Fixation')
+	line_n = _np.argmin(abs(text_block.line_positions - fixation.y))
+	distribution = _np.zeros((text_block.n_rows, text_block.n_cols-(n-1)), dtype=float)
+	for ngram, rc in text_block.ngrams(n, line_n=line_n, yield_rc=True):
+		distance = _distance(fixation.xy, ngram.center)
+		distribution[rc] = _np.exp(-distance**2 / (2 * gamma**2))
+	return distribution / distribution.sum()
