@@ -8,11 +8,22 @@ Defines classes for dealing with texts, most notably the
 
 import re as _re
 import numpy as _np
-from fontTools.ttLib import TTFont as _TTFont
-from matplotlib import font_manager as _font_manager
+from PIL import ImageFont as _ImageFont
 
 
-_IA_REGEX = _re.compile(r'(\[(.+?)\]\{(.+?)\})')
+ALPHABETS = {
+	'Dutch': 'A-Za-z',
+	'English': 'A-Za-z',
+	'French': 'A-ZÇÉÀÈÙÂÊÎÔÛËÏÜŸŒa-zçéàèùâêîôûëïüÿœ',
+	'German': 'A-ZÄÖÜa-zäöüß',
+	'Greek': 'ΑΒΓΔΕΖΗΘΙΚΛΜΝΞΟΠΡΣΣΤΥΦΧΨΩΆΈΉΊΌΎΏΪΫΪ́Ϋ́αβγδεζηθικλμνξοπρσςτυφχψωάέήίόύώϊϋΐΰ',
+	'Italian': 'A-ZÀÉÈÍÌÓÒÚÙa-zàéèíìóòúù',
+	'Polish': 'A-ZĄĆĘŁŃÓŚŹŻa-ząćęłńóśźż',
+	'Portuguese': 'A-ZÁÂÃÀÇÉÊÍÓÔÕÚa-záâãàçéêíóôõú',
+	'Russian': 'АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯабвгдеёжзийклмнопрстуфхцчшщъыьэюя',
+	'Spanish': 'A-ZÑÁÉÍÓÚÜa-zñáéíóúü'
+}
+_ZONE_REGEX = _re.compile(r'(\[(.+?)\]\{(.+?)\})')
 _ALPHABET = 'A-Za-z'
 _ALPHA = _re.compile(f'[{_ALPHABET}]')
 _ALPHA_PLUS = _re.compile(f'[{_ALPHABET}]+')
@@ -22,16 +33,23 @@ def set_default_alphabet(alphabet):
 	'''
 
 	By default, Eyekit considers the alphabet to be the standard 26 Latin
-	characters in upper and lower case. If you are working with another
-	language it may be useful to change this default, so that all new
-	`TextBlock` objects are automatically initialized with another
-	alphabet. To do this, call `set_default_alphabet()` at the top of
-	your script. For German, for example, you might do this:
+	characters in upper and lower case. If you are working with another language
+	it may be useful to change this default, so that all new `TextBlock` objects
+	are automatically initialized with a particular alphabet. To do this, call
+	`set_default_alphabet()` at the top of your script. For German, for example,
+	you might do this:
 
 	```
 	eyekit.set_default_alphabet('A-Za-zßÄÖÜäöü')
 	```
 
+	Eyekit also provides built-in alphabets for several European languages, so
+	it's also possible to do this:
+
+	```
+	eyekit.set_default_alphabet(eyekit.ALPHABETS['Polish'])
+	```
+
 	'''
 	global _ALPHABET, _ALPHA, _ALPHA_PLUS
 	if not isinstance(alphabet, str):
@@ -55,6 +73,16 @@ class Box(object):
 			return True
 		return False
 
+	@property
+	def x(self):
+		'''*float* X-coordinate of the center of the bounding box'''
+		return self.x_tl + self.width / 2
+	
+	@property
+	def y(self):
+		'''*float* Y-coordinate of the center of the bounding box'''
+		return self.y_tl + self.height / 2
+
 	@property
 	def x_tl(self):
 		'''*float* X-coordinate of the top-left corner of the bounding box'''
@@ -93,7 +121,7 @@ class Box(object):
 	@property
 	def center(self):
 		'''*tuple* XY-coordinates of the center of the bounding box'''
-		return self.x_tl + self.width / 2, self.y_tl + self.height / 2
+		return self.x, self.y
 
 
 class Character(Box):
@@ -108,19 +136,21 @@ class Character(Box):
 
 	'''
 
-	def __init__(self, char, x_tl, y_tl, x_br, y_br):
+	def __init__(self, char, x_tl, y_tl, x_br, y_br, baseline):
 		if isinstance(char, str) and len(char) == 1:
 			self._char = char
 		else:
 			raise ValueError('char must be one-letter string')
 		self._x_tl, self._y_tl = float(x_tl), float(y_tl)
 		self._x_br, self._y_br = float(x_br), float(y_br)
+		self._baseline = float(baseline)
 
 	def __repr__(self):
 		return self._char
 
-	def __str__(self):
-		return self._char
+	@property
+	def baseline(self):
+		return self._baseline
 
 
 class InterestArea(Box):
@@ -131,7 +161,7 @@ class InterestArea(Box):
 	is of potenital interest. It is not usually necessary to create
 	`InterestArea` objects manually; they are created automatically when
 	you slice a `TextBlock` object or when you iterate over lines, words,
-	characters, ngrams, or parsed interest areas.
+	characters, ngrams, or zones parsed from the raw text.
 
 	'''
 
@@ -149,11 +179,8 @@ class InterestArea(Box):
 	def __repr__(self):
 		return 'InterestArea[%s]' % self.label
 
-	def __str__(self):
-		return self.text
-
 	def __getitem__(self, key):
-		self._chars[key]
+		return self._chars[key]
 
 	def __len__(self):
 		return len(self._chars)
@@ -162,9 +189,13 @@ class InterestArea(Box):
 		for char in self._chars:
 			yield char	
 
+	@property
+	def baseline(self):
+		return self._chars[0].baseline
+
 	@property
 	def text(self):
-		'''*str* String represention of the interest area; same as calling `str()`'''
+		'''*str* String represention of the interest area'''
 		return ''.join(map(str, self._chars))
 
 	@property
@@ -189,66 +220,70 @@ class TextBlock(Box):
 
 	'''
 
-	def __init__(self, text, position, font_name, font_size, line_spacing=1.0, alphabet=None):
+	def __init__(self, text, position, font_name, font_size, line_height=None, adjust_bbox=None, alphabet=None):
 		'''Initialized with:
 
-		- ```text``` *str* (single line) | *list* of *str* (multiline) : The line or lines of text. Optionally, these can be marked up with arbitrary interest areas; for example, ```The quick brown fox jump[ed]{past-suffix} over the lazy dog```.
+		- ```text``` *str* (single line) | *list* of *str* (multiline) : The line or lines of text. Optionally, these can be marked up with arbitrary interest areas (or zones); for example, ```The quick brown fox jump[ed]{past-suffix} over the lazy dog```.
 		- `position` *tuple*[*float*, *float*] : XY-coordinates of the top left corner of the `TextBlock`'s bounding box.
-		- `font_name` *str* : Name of a font available on your system. Eyekit can access TrueType fonts that are discoverable by Matplotlib's FontManager.
-		- `font_size` *float* : Font size in points.
-		- `line_spacing` *float* : Amount of line spacing (1 for single line spacing, 2 for double line spacing, etc.)
-		- `alphabet` *str* : A string of characters that are considered alphabetical. This is case sensitive, so you must supply upper- and lower-case variants. By default, the alphabet is set to `A-Za-z`, but for German, for example, you might use this: `A-Za-zßÄÖÜäöü`. If you are creating many `TextBlock` objects with the same alphabet, it may be preferable to use `set_default_alphabet()`.
+		- `font_name` *str* : Name of a font available on your system. Eyekit can access TrueType fonts that are discoverable by Pillow.
+		- `font_size` *float* : Font size in points (at 72dpi). To convert a font size from some other dpi, use `eyekit.tools.font_size_at_72dpi()`.
+		- `line_height` *float* : Height of a line of text in points. Generally speaking, for single line spacing, the line height is equal to the font size, for double line spacing, the light height is equal to 2 × the font size, etc. By default, the line height is assumed to be the same as the font size (single line spacing). This parameter also effectively determines the height of the bounding boxes around interest areas.
+		- `adjust_bbox` *float* : Pixel adjustment to the y-position of bounding boxes relative to the font baseline. Some fonts, such as Courier and Helvetica have quite high baselines making the bounding boxes a little low relative to the text. This parameter can be used to adjust this.
+		- `alphabet` *str* : A string of characters that are considered alphabetical. This is case sensitive, so you must supply upper- and lower-case variants. By default, the alphabet is set to `A-Za-z`, but for German, for example, you might use this: `A-Za-zßÄÖÜäöü`. Eyekit also provides built-in alphabets for several European languages, for example, `eyekit.ALPHABETS['French']`. If you are creating many `TextBlock` objects with the same alphabet, it may be preferable to use `set_default_alphabet()`.
 		'''
+
+		# TEXT
 		if isinstance(text, str):
 			self._text = [text]
 		elif isinstance(text, list):
 			self._text = [str(line) for line in text]
 		else:
 			raise ValueError('text should be a string or a list of strings')
-		
+
+		# POSITION
 		try:
 			self._x_tl = float(position[0])
 			self._y_tl = float(position[1])
 		except:
 			raise ValueError('position should be tuple representing the XY coordinates of the top left corner of the TextBlock')
 
-		if not isinstance(font_name, str):
-			raise ValueError('font_name shoud be a string')
-		self._font = _load_font(font_name)
-		self._font_name = font_name
+		# FONT NAME AND SIZE
+		self._font_name = str(font_name)
+		self._font_size = float(font_size)
 
-		try:
-			self._font_size = float(font_size)
-		except:
-			raise ValueError('font_size should be numeric')
-		if self._font_size < 1:
-			raise ValueError('font_size should be at least 1pt')
+		# LINE HEIGHT
+		if line_height is None:
+			self._line_height = self._font_size
+		else:
+			self._line_height = float(line_height)
 
-		try:
-			self._line_spacing = float(line_spacing)
-		except:
-			raise ValueError('line_spacing should be numeric')
-		if self._line_spacing < 0.5:
-			raise ValueError('line_spacing should be at least 0.5')
-		self._line_height = self._font_size * self._line_spacing
+		# BOUNDING BOX ADJUSTMENT
+		if adjust_bbox is None:
+			self._adjust_bbox = 0
+		else:
+			self._adjust_bbox = float(adjust_bbox)
 
+		# ALPHABET
 		self.alphabet = alphabet
 
-		self._characters, self._interest_areas = self._initialize_text_block()
+		# LOAD FONT
+		try:
+			self._font = _ImageFont.truetype(self._font_name, int(self._font_size * 64)).font # font_size must be int, so we'll work with a much larger font size and scale the widths back down later for greater precision
+		except:
+			raise ValueError(f'Unable to load font "{self._font_name}" in size {self._font_size}.')
+		self._first_baseline = self._y_tl + (self._font.ascent - self._font.descent) / 64
+		self._half_space_width = self._font.getsize(' ')[0][0] / 128
 
-		self._x_br = 0.0
-		for line in self._characters:
-			end_x_br = line[-1].x_br
-			if end_x_br > self._x_br:
-				self._x_br = end_x_br
+		# INITIALIZE CHARACTERS AND ZONES
+		self._characters, self._zones = self._initialize_text_block()
+
+		# SET BOTTOM-RIGHT CORNER OF BOUNDING BOX
+		self._x_br = max([line[-1].x_br for line in self._characters])
 		self._y_br = self._y_tl + self.n_rows * self._line_height
 
 	def __repr__(self):
 		return 'TextBlock[%s...]' % ''.join(map(str, self._characters[0][:16]))
 
-	def __str__(self):
-		return ' '.join([''.join(map(str, line)) for line in self._characters])
-
 	def __getitem__(self, key):
 		'''
 		Subsetting a TextBlock object with a row,column index returns
@@ -285,6 +320,11 @@ class TextBlock(Box):
 			for char in line:
 				yield char
 
+	@property
+	def text(self):
+		'''*str* String represention of the text`'''
+		return ' '.join([''.join(map(str, line)) for line in self._characters])
+
 	@property
 	def font_name(self):
 		'''*str* Name of the font'''
@@ -296,14 +336,14 @@ class TextBlock(Box):
 		return self._font_size
 
 	@property
-	def line_spacing(self):
-		'''*float* Line spacing (single, double, etc.)'''
-		return self._line_spacing
+	def line_height(self):
+		'''*float* Line height in points'''
+		return self._line_height
 
 	@property
-	def line_height(self):
-		'''*float* Pixel distance between lines'''
-		return self._line_height
+	def adjust_bbox(self):
+		'''*float* Line height in points'''
+		return self._adjust_bbox
 
 	@property
 	def alphabet(self):
@@ -345,36 +385,36 @@ class TextBlock(Box):
 	# PUBLIC METHODS
 	################
 
-	def interest_areas(self):
+	def zones(self):
 		'''
 
-		Iterate over each `InterestArea` parsed from the raw text during
-		initialization.
+		Iterate over each marked up zone as an `InterestArea`.
 		
 		'''
-		for _, interest_area in self._interest_areas.items():
-			yield interest_area
+		for _, zone in self._zones.items():
+			yield zone
 
-	def which_interest_area(self, fixation):
+	def which_zone(self, fixation):
 		'''
 
-		Returns the parsed `InterestArea` that the fixation falls inside
+		Return the marked-up zone that the fixation falls inside as an
+		`InterestArea`.
 
 		'''
-		for interest_area in self.interest_areas():
-			if fixation in interest_area:
-				return interest_area
+		for zone in self.zones():
+			if fixation in zone:
+				return zone
 		return None
 
-	def get_interest_area(self, label):
+	def get_zone(self, label):
 		'''
 
-		Retrieve a parsed `InterestArea` by its label.
+		Retrieve a marked-up zone by its label.
 		
 		'''
-		if label not in self._interest_areas:
-			raise KeyError('There is no interest area with the label %s' % label)
-		return self._interest_areas[label]
+		if label not in self._zones:
+			raise KeyError('There is no zone with the label %s' % label)
+		return self._zones[label]
 
 	def lines(self):
 		'''
@@ -388,7 +428,7 @@ class TextBlock(Box):
 	def which_line(self, fixation):
 		'''
 
-		Returns the line `InterestArea` that the fixation falls inside
+		Return the line that the fixation falls inside as an `InterestArea`.
 
 		'''
 		for line in self.lines():
@@ -396,15 +436,17 @@ class TextBlock(Box):
 				return line
 		return None
 
-	def words(self, pattern=None, add_padding=True):
+	def words(self, pattern=None, line_n=None, add_padding=True):
 		'''
 
 		Iterate over each word as an `InterestArea`. Optionally, you can
-		supply a regex pattern to pick out only certain words. For example,
-		`'[Tt]he'` gives you all occurances of the word *the* or
-		`'[a-z]+ing'` gives you all words ending *-ing*. `add_padding` adds
-		a little extra width to each word's bounding box, so that they cover
-		the adjoining spaces or punctuation.
+		supply a regex pattern to define what constitutes a word or to pick
+		out specific words. For example, `r'\\b[Tt]he\\b'` gives you all
+		occurances of the word *the* or `'[a-z]+ing'` gives you all words
+		ending with *-ing*. `add_padding` adds half of the width of a space
+		character to the left and right edges of the word's bounding box, so
+		that fixations that fall on a space between two words will at least
+		fall into one of the two words' bounding boxes.
 
 		'''
 		if pattern is None:
@@ -412,11 +454,13 @@ class TextBlock(Box):
 		else:
 			pattern = _re.compile(pattern)
 		if add_padding:
-			padding = self._get_character_width(' ') / 2
+			padding = self._half_space_width
 		else:
 			padding = 0
 		word_i = 0
 		for r, line in enumerate(self._characters):
+			if line_n is not None and r != line_n:
+				continue
 			line_str = ''.join(map(str, line))
 			for word in pattern.findall(line_str):
 				c = line_str.find(word)
@@ -424,45 +468,48 @@ class TextBlock(Box):
 				yield InterestArea(self._characters[r][c:c+len(word)], 'word_%i'%word_i, padding=padding)
 				word_i += 1
 
-	def which_word(self, fixation, add_padding=True):
+	def which_word(self, fixation, pattern=None, line_n=None, add_padding=True):
 		'''
 
-		Returns the word `InterestArea` that the fixation falls inside.
-		`add_padding` adds a little extra width to each word's bounding
-		box, so that they cover the adjoining spaces or punctuation.
+		Return the word that the fixation falls inside as an `InterestArea`.
+		For the meaning of `pattern` and `add_padding` see
+		`TextBlock.words()`.
 
 		'''
-		for word in self.words(add_padding):
+		for word in self.words(pattern, line_n, add_padding):
 			if fixation in word:
 				return word
 		return None
 
-	def characters(self, alphabetical_only=True):
+	def characters(self, line_n=None, alphabetical_only=True):
 		'''
 
 		Iterate over each character as an `InterestArea`.
 
 		'''
 		char_i = 0
-		for line in self._characters:
+		for r, line in enumerate(self._characters):
+			if line_n is not None and r != line_n:
+				continue
 			for char in line:
 				if alphabetical_only and not self._alpha.match(str(char)):
 					continue
 				yield InterestArea([char], 'character_%i'%char_i)
 				char_i += 1
 
-	def which_character(self, fixation, alphabetical_only=True):
+	def which_character(self, fixation, line_n=None, alphabetical_only=True):
 		'''
 
-		Returns the character `InterestArea` that the fixation falls inside
+		Return the character that the fixation falls inside as an
+		`InterestArea`.
 
 		'''
-		for character in self.characters(alphabetical_only):
+		for character in self.characters(line_n, alphabetical_only):
 			if fixation in character:
 				return character
 		return None
 
-	def ngrams(self, n):
+	def ngrams(self, n, line_n=None, alphabetical_only=True, yield_rc=False):
 		'''
 
 		Iterate over each ngram, for given n, as an `InterestArea`.
@@ -470,152 +517,76 @@ class TextBlock(Box):
 		'''
 		ngram_i = 0
 		for r, line in enumerate(self._characters):
+			if line_n is not None and r != line_n:
+				continue
 			for c in range(len(line)-(n-1)):
-				yield InterestArea(line[c:c+n], '%igram_%i'%(n, ngram_i))
+				if alphabetical_only and not self._alpha_plus.fullmatch(''.join(map(str, line[c:c+n]))):
+					continue
+				ngram = InterestArea(line[c:c+n], '%igram_%i'%(n, ngram_i))
+				if yield_rc:
+					yield ngram, (r, c)
+				else:
+					yield ngram
 				ngram_i += 1
 
 	# No which_ngram() method because, by definition, a fixation is
 	# inside multiple ngrams.
 
-	def in_bounds(self, fixation, threshold):
-		'''
-		Returns `True` if the given fixation is within a certain threshold of
-		any character in the text. Returns `False` otherwise.
-		'''
-		for char in self:
-			if _distance(fixation.xy, char.xy) <= threshold:
-				return True
-		return False
+	#################
+	# PRIVATE METHODS
+	#################
 
-	def p_ngrams_fixation(self, fixation, n, gamma=30, line_only=True):
-		'''
-		Given a fixation, return probability distribution over ngrams in the
-		text (or, optionally, just the line), representing the
-		probability that each ngram is being "seen".
-		'''
-		if line_only:
-			target_line = _np.argmin(abs(self.line_positions - fixation.y))
-		else:
-			target_line = None
-		distribution = _np.zeros((self.n_rows, self.n_cols-(n-1)), dtype=float)
-		for ngram in self.iter_ngrams(n, line_n=target_line):
-			distribution[ngram[0].rc] = self._p_ngram_fixation(ngram, fixation, gamma, line_only)
-		return distribution / distribution.sum()
-
-	def todict(self):
+	def _serialize(self):
 		'''
 		
 		Returns the `TextBlock`'s ininialization arguments as a dictionary
 		for serialization.
 		
 		'''
-		dic = {}
-		dic['position'] = self.x_tl, self.y_tl
-		dic['font_name'] = self.font_name
-		dic['font_size'] = self.font_size
-		dic['line_spacing'] = self.line_spacing
-		dic['alphabet'] = self.alphabet
-		dic['text'] = self._text
-		return dic
-
-	#################
-	# PRIVATE METHODS
-	#################
+		return {'position': (self.x_tl, self.y_tl), 'font_name': self.font_name, 'font_size': self.font_size, 'line_height': self.line_height, 'adjust_bbox':self.adjust_bbox, 'alphabet': self.alphabet, 'text': self._text}
 
 	def _initialize_text_block(self):
 		'''
 
-		Parses out any marked up interest areas from the text and then
-		converts and stores every character as a Character object with the
+		Parses out any marked up interest areas from the text and converts
+		and stores every character as a Character object with the
 		appropriate character width.
 
 		'''
 		characters = []
-		interest_areas = {}
-		y_tl = self.y_tl
+		zones = {}
+		y_tl = self.y_tl - (self._line_height - self._font_size) / 2 + self._adjust_bbox # y_tl of character bounding boxes on first lines
+		baseline = self._first_baseline
 		for r, line in enumerate(self._text):
-			for IA_markup, IA_text, IA_label in _IA_REGEX.findall(line):
-				if IA_label in interest_areas:
-					raise ValueError('The interest area label %s has been used more than once.' % IA_label)
-				c = line.find(IA_markup)
-				interest_areas[IA_label] = (r, c, len(IA_text))#InterestArea([], IA_label) # THIS NEEDS TO BE FIXED - cannot create IA yet, because no chars created
-				line = line.replace(IA_markup, IA_text)
+			# Parse and strip out interest area zones from this line
+			for zone_markup, zone_text, zone_label in _ZONE_REGEX.findall(line):
+				if zone_label in zones:
+					raise ValueError('The zone label %s has been used more than once.' % zone_label)
+				c = line.find(zone_markup)
+				zones[zone_label] = (r, c, len(zone_text)) # record row index, column index, and length of zone
+				line = line.replace(zone_markup, zone_text) # replace the marked up zone with the unmarked up text
+			# Create the set of Character objects for this line
 			characters_line = []
-			x_tl = self.x_tl
-			for c, char in enumerate(line):
-				character_width = self._get_character_width(char)
-				character = Character(char, x_tl, y_tl, x_tl+character_width, y_tl+self.line_height)
-				characters_line.append(character)
-				x_tl += character_width
+			x_tl = self.x_tl # x_tl of first character bounding box on this line
+			y_br = y_tl + self._line_height # y_br of all character bounding boes on this line
+			line_width = self._font.getsize(line)[0][0] # anticipate the length of the line
+			words = line.split(' ')
+			word_widths = [(word + ' ', self._font.getsize(word + ' ')[0][0]) for word in words[:-1]]
+			word_widths.append((words[-1], self._font.getsize(words[-1])[0][0])) # calculate word widths - all words include a trailing space except the last word in the line
+			line_scaling_factor = line_width / sum([width for _, width in word_widths]) # calculate scaling factor needed to scale down the word widths so that their sum width matches the anticipated line width
+			for word, word_width in word_widths:
+				word_width *= line_scaling_factor # scale down the word width
+				char_widths = [self._font.getsize(char)[0][0] for char in word]
+				word_scaling_factor = word_width / sum(char_widths) # calculate a scaling factor for scaling down character widths so that their sum width matches the target word length
+				for char, char_width in zip(word, char_widths):
+					char_width *= word_scaling_factor
+					char_width /= 64
+					characters_line.append(Character(char, x_tl, y_tl, x_tl+char_width, y_br, baseline))
+					x_tl += char_width
 			characters.append(characters_line)
-			y_tl += self.line_height
-		for IA_label, (r, c, length) in interest_areas.items():
-			interest_areas[IA_label] = InterestArea(characters[r][c:c+length], IA_label)
-		return characters, interest_areas
-
-	def _get_character_width(self, char):
-		'''
-
-		Compute the character width in the TextBlock's font.
-		
-		'''
-		try:
-			character_location = self._font['cmap'][ord(char)]
-		except KeyError as exception:
-			exception.args = (f'The character "{char}" is not available in "{self.font_name}".',)
-			raise 
-		character_width = self._font['glyph_set'][character_location].width
-		return character_width * self._font_size / self._font['units_per_em']
-
-	def _p_ngram_fixation(self, ngram, fixation, gamma, line_only):
-		'''
-		Returns the unnormalized probability that the participant is
-		"seeing" an ngram given a fixation.
-		'''
-		if line_only:
-			distances = [abs(fixation.x - char.x) for char in ngram]
-		else:
-			distances = [_distance(fixation.xy, char.xy) for char in ngram]
-		averagedistance = sum(distances) / len(distances)
-		return _np.exp(-averagedistance**2 / (2 * gamma**2))
-
-def _distance(point1, point2):
-	'''
-	Returns the Euclidean distance between two points.
-	'''
-	return _np.sqrt(sum([(a - b)**2 for a, b in zip(point1, point2)]))
-
-def _memoize(f):
-    memo = {}
-    def helper(x):
-        if x not in memo:            
-            memo[x] = f(x)
-        return memo[x]
-    return helper
-
-@_memoize
-def _load_font(font_name):
-	'''
-
-	Given a font name, attempt to find its TrueType file on the system
-	using Matplotlib's FontManager and then use fontTools to extract the
-	character map, glyph set, and em size. The output of this function is
-	memoized, so that this slow process doesn't have to be performed many
-	times for the same font.
-
-	'''
-	fm = _font_manager.FontManager()
-	try:
-		
-		font_path = fm.findfont(_font_manager.FontProperties([font_name]), fallback_to_default=False)
-	except Exception as exception:
-		exception.args = (f'Failed to find the font "{font_name}" on this system.',)
-		raise
-	try:
-		font = _TTFont(font_path, fontNumber=0)
-		cmap = font['cmap'].getBestCmap()
-		glyph_set = font.getGlyphSet()
-		units_per_em = font['head'].unitsPerEm
-	except Exception as exception:
-		exception.args = (f'Cannot properly handle the font "{font_name}".',)
-	return {'cmap':cmap, 'glyph_set':glyph_set, 'units_per_em':units_per_em}
+			y_tl += self._line_height
+			baseline += self._line_height
+		# Set up and store the zoned interest areas based on the indices stored earlier.
+		for zone_label, (r, c, length) in zones.items(): # Needs to be done in two steps because IAs can't be computed until character positions are known
+			zones[zone_label] = InterestArea(characters[r][c:c+length], zone_label)
+		return characters, zones
